@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.7.") or
-    raise "ruby lib version (2.7.2) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.7.4) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.7.0/x86_64-linux")
@@ -21,14 +21,14 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "7"
-  CONFIG["TEENY"] = "2"
-  CONFIG["PATCHLEVEL"] = "137"
+  CONFIG["TEENY"] = "4"
+  CONFIG["PATCHLEVEL"] = "191"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr")
-  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)"
-  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)"
-  CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME)"
+  CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)-2.7"
+  CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)-2.7"
+  CONFIG["RUBY_SO_NAME"] = "ruby-2.7"
   CONFIG["exec"] = "exec"
   CONFIG["ruby_pc"] = "ruby-2.7.pc"
   CONFIG["CC_WRAPPER"] = ""
@@ -44,7 +44,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt'"
+  CONFIG["configure_args"] = " '--prefix=/usr' '--program-suffix=-2.7' '--with-soname=ruby-2.7' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' '--disable-install-doc' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' 'CPPFLAGS=-D_FORTIFY_SOURCE=2' 'CXXFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -145,8 +145,8 @@ module RbConfig
   CONFIG["CP"] = "cp"
   CONFIG["RM"] = "rm -f"
   CONFIG["PKG_CONFIG"] = "pkg-config"
-  CONFIG["DOXYGEN"] = "doxygen"
-  CONFIG["DOT"] = "dot"
+  CONFIG["DOXYGEN"] = ""
+  CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
   CONFIG["MKDIR_P"] = "/usr/bin/mkdir -p"
   CONFIG["INSTALL_DATA"] = "$(INSTALL) -m 644"
@@ -165,7 +165,7 @@ module RbConfig
   CONFIG["AR"] = "ar"
   CONFIG["RANLIB"] = "ranlib"
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "gcc (GCC) 10.2.0\nCopyright (C) 2020 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "gcc (GCC) 11.1.0\nCopyright (C) 2021 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["MJIT_CC"] = "/usr/bin/gcc"
   CONFIG["CSRCFLAG"] = ""
@@ -175,11 +175,11 @@ module RbConfig
   CONFIG["GNU_LD"] = "yes"
   CONFIG["LD"] = "ld"
   CONFIG["GCC"] = "yes"
+  CONFIG["CXXFLAGS"] = "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt"
+  CONFIG["CXX"] = "g++"
   CONFIG["EGREP"] = "/usr/bin/grep -E"
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CXXFLAGS"] = "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt"
-  CONFIG["CXX"] = "g++"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = "-D_FORTIFY_SOURCE=2 $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -fstack-protector-strong -rdynamic -Wl,-export-dynamic"
@@ -189,7 +189,7 @@ module RbConfig
   CONFIG["target_vendor"] = "pc"
   CONFIG["target_cpu"] = "x86_64"
   CONFIG["target"] = "x86_64-pc-linux-gnu"
-  CONFIG["host_os"] = "linux-gnu"
+  CONFIG["host_os"] = "linux"
   CONFIG["host_vendor"] = "pc"
   CONFIG["host_cpu"] = "x86_64"
   CONFIG["host"] = "x86_64-pc-linux-gnu"
@@ -235,6 +235,7 @@ module RbConfig
   CONFIG["libexecdir"] = "$(DESTDIR)/usr/lib/ruby"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
+  CONFIG["program_transform_name"] = "s&$$&-2.7&;s&^&&"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["PACKAGE_URL"] = ""
   CONFIG["PACKAGE_BUGREPORT"] = ""
